searchNodes=[{"doc":"Module for working with uncompressed frames of YCbCr videos. Only a subset of color spaces are supported ( C420 , C444 ), all others ( C420jpeg , C420paldv , C422 , Cmono ) are missing. Open file and count frames in file Y4m.stream returns a tuple of metadata and a lazy stream. iex&gt; { props , stream } = Y4m . stream ( &quot;test/videos/example.y4m&quot; ) iex&gt; props %{ aspect_ratio : [ 0 , 0 ] , color_space : :C420 , frame_rate : [ 25 , 1 ] , height : 288 , interlacing : :progressive , width : 384 } # get number of frames iex&gt; stream |&gt; Enum . to_list ( ) |&gt; length ( ) 51 Using the Stream The metadata dictionary contains information about the resolution, color space and framerate as specified by the file header. The stream is read directly from file. That means that the streams state is implicitly handled by the file handle. When taking a frame from the stream, the stream will continue with the next frame in the file. This may lead to confusion as a hidden shared state is involved. Each frame is a list of binaries. iex&gt; { _props , stream } = Y4m . stream ( &quot;test/videos/example.y4m&quot; ) iex&gt; [ &lt;&lt; _y :: binary &gt;&gt; , &lt;&lt; _u :: binary &gt;&gt; , &lt;&lt; _v :: binary &gt;&gt; ] = Enum . at ( stream , 0 ) iex&gt; # frames do not match because of shared state iex&gt; Enum . at ( stream , 0 ) != Enum . at ( stream , 0 ) true Looping a file Sometimes it's useful to loop a video in file. This can be done using GenServer to explicitly capture the frame streams state and to reopen the file as needed: iex&gt; defmodule Y4mLoop do ...&gt; use GenServer ...&gt; ...&gt; def start_link ( file_path ) , do : GenServer . start_link ( __MODULE__ , file_path ) ...&gt; def next ( loop ) , do : GenServer . call ( loop , :next ) ...&gt; def properties ( loop ) , do : GenServer . call ( loop , :properties ) ...&gt; ...&gt; @impl true ...&gt; def init ( file_path ) do ...&gt; { props , stream } = Y4m . stream ( file_path ) ...&gt; { :ok , { file_path , props , stream } } ...&gt; end ...&gt; ...&gt; @impl true ...&gt; def handle_call ( :next , _from , { file_path , props , stream } ) do ...&gt; case stream |&gt; Enum . take ( 1 ) do ...&gt; [ frame ] -&gt; ...&gt; { :reply , frame , { file_path , props , stream } } ...&gt; ...&gt; [ ] -&gt; ...&gt; # reopen video file ...&gt; { props , stream } = Y4m . stream ( file_path ) ...&gt; [ frame ] = stream |&gt; Enum . take ( 1 ) ...&gt; { :reply , frame , { file_path , props , stream } } ...&gt; end ...&gt; end ...&gt; ...&gt; @impl true ...&gt; def handle_call ( :properties , _from , { file_path , props , stream } ) do ...&gt; { :reply , props , { file_path , props , stream } } ...&gt; end ...&gt; end ...&gt; iex&gt; # load file with fewer than 420 frames iex&gt; { :ok , loop } = Y4mLoop . start_link ( &quot;test/videos/example.y4m&quot; ) iex&gt; 1 .. 420 |&gt; Enum . map ( fn _i -&gt; Y4mLoop . next ( loop ) end )","ref":"Y4m.html","title":"Y4m","type":"module"},{"doc":"","ref":"Y4m.html#append/2","title":"Y4m.append/2","type":"function"},{"doc":"Same as stream/2","ref":"Y4m.html#stream/1","title":"Y4m.stream/1","type":"function"},{"doc":"Reads y4m frames from a file on disk. Returns parsed file header and lazy stream across all frames in file. Examples iex&gt; { :ok , file } = File . open ( &quot;test/videos/example.y4m&quot; ) iex&gt; { _props , stream } = Y4m . stream ( file ) iex&gt; stream |&gt; Enum . take ( 10 )","ref":"Y4m.html#stream/2","title":"Y4m.stream/2","type":"function"},{"doc":"","ref":"Y4m.html#write/3","title":"Y4m.write/3","type":"function"},{"doc":"Data buffer for fragmented y4m streams. Buffer will accept data and return either the properties or frames, once enough data is present.","ref":"Y4m.Buffer.html","title":"Y4m.Buffer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Y4m.Buffer.html#child_spec/1","title":"Y4m.Buffer.child_spec/1","type":"function"},{"doc":"Push data into the buffer.","ref":"Y4m.Buffer.html#push/2","title":"Y4m.Buffer.push/2","type":"function"},{"doc":"","ref":"Y4m.Buffer.html#start_link/1","title":"Y4m.Buffer.start_link/1","type":"function"},{"doc":"","ref":"Y4m.Buffer.State.html","title":"Y4m.Buffer.State","type":"module"},{"doc":"","ref":"Y4m.FrameParser.html","title":"Y4m.FrameParser","type":"module"},{"doc":"Read the next frame from the file . Frame length in bytes depends on width , height and color_space .","ref":"Y4m.FrameParser.html#next_frame/4","title":"Y4m.FrameParser.next_frame/4","type":"function"},{"doc":"","ref":"Y4m.FrameParser.html#plane_lengths/3","title":"Y4m.FrameParser.plane_lengths/3","type":"function"},{"doc":"Parser to deserialize y4m file header according to the specification found here: https://wiki.multimedia.cx/index.php/YUV4MPEG2","ref":"Y4m.HeaderParser.html","title":"Y4m.HeaderParser","type":"module"},{"doc":"Deserialize first line in y4m file.","ref":"Y4m.HeaderParser.html#parse/1","title":"Y4m.HeaderParser.parse/1","type":"function"},{"doc":"","ref":"Y4m.Stream.html","title":"Y4m.Stream","type":"module"},{"doc":"Initialize a Stream of y4m frames. The file header is read immediately, but frames are evaluated on demand.","ref":"Y4m.Stream.html#init/2","title":"Y4m.Stream.init/2","type":"function"},{"doc":"","ref":"Y4m.Stream.html#t:option/0","title":"Y4m.Stream.option/0","type":"type"},{"doc":"","ref":"Y4m.Stream.html#t:options/0","title":"Y4m.Stream.options/0","type":"type"},{"doc":"","ref":"Y4m.Writer.html","title":"Y4m.Writer","type":"module"},{"doc":"","ref":"Y4m.Writer.html#append/2","title":"Y4m.Writer.append/2","type":"function"},{"doc":"","ref":"Y4m.Writer.html#close/1","title":"Y4m.Writer.close/1","type":"function"},{"doc":"","ref":"Y4m.Writer.html#init/2","title":"Y4m.Writer.init/2","type":"function"}]